ResolutionOutcome

Enum ResolutionOutcome 

pub enum ResolutionOutcome {
    Resolved,
    Ambiguous,
    Missing,
}
Final classification of a traced lookup.

ResolutionTrace::target is present exactly when the outcome is Resolved. An unscoped lookup is ambiguous when multiple applicable candidates exist. Scoped lookups report an unresolved lookup as Missing, even when other modules define the same name.

Variants



Resolved

The lookup selected one target.



Ambiguous

An unscoped lookup found multiple applicable candidates.



Missing

The applicable resolver rules did not select a target.