pub struct ResolutionScope {
pub module: ModuleId,
pub module_name: String,
pub source_label: Option<String>,
pub last_updated: String,
}Expand description
Exact loaded module version used as a resolution scope.
Fields
module: ModuleIdIdentifies the exact loaded module version used as the scope.
module_name: StringNames the scoped module.
source_label: Option<String>Identifies the scoped module’s source when the loader assigned a label.
last_updated: StringContains the module’s LAST-UPDATED value, or an empty string when absent.