pub enum ImportResolutionMode {
Direct,
Alias,
Forwarded,
Partial,
Unresolved,
Cycle,
}Expand description
Resolver strategy used for one imported symbol.
Variants
Direct
The selected source module directly defines the complete import group.
Alias
A well-known source-module alias selected the defining module.
Forwarded
The declared source module forwarded the complete import group.
Partial
The symbol was retained while resolving a mixed direct/forwarded group.
Unresolved
No source module candidate could resolve the symbol.
Cycle
No target was selected and at least one candidate path was cyclic.