pub enum PositionError {
OffsetOutOfBounds {
offset: ByteOffset,
len: ByteOffset,
},
LineOutOfBounds {
line: u32,
line_count: usize,
},
ByteColumnOutOfBounds {
line: u32,
column: u32,
max_column: u32,
},
CharacterOutOfBounds {
line: u32,
character: u32,
max_character: u32,
encoding: PositionEncoding,
},
OffsetInsideLineTerminator {
offset: ByteOffset,
line: u32,
},
MidCodePoint {
offset: ByteOffset,
},
MidUtf16Surrogate {
line: u32,
character: u32,
},
InvalidUtf8 {
valid_up_to: ByteOffset,
error_len: Option<usize>,
},
}Expand description
Failure to convert between byte offsets, byte positions, and editor positions.
Variants
OffsetOutOfBounds
A byte offset lies beyond EOF.
LineOutOfBounds
A zero-based line does not exist.
ByteColumnOutOfBounds
A byte column does not identify a byte or the final EOF position.
CharacterOutOfBounds
An editor character lies beyond the logical end of its line.
OffsetInsideLineTerminator
A byte offset falls between the CR and LF bytes of a CRLF terminator.
MidCodePoint
A UTF-8 position falls within a multi-byte code point.
Fields

offset: ByteOffsetMidUtf16Surrogate
A UTF-16 position falls between the surrogate code units of an astral character.
InvalidUtf8
Editor conversion requires a valid UTF-8 source document.