pub enum SourceRangeError {
UnrepresentableOffset {
offset: usize,
max: usize,
},
OffsetOutOfBounds {
offset: ByteOffset,
len: ByteOffset,
},
ReversedRange {
start: ByteOffset,
end: ByteOffset,
},
SourceMismatch {
expected: SourceId,
actual: SourceId,
},
SourceTooLarge {
len: usize,
max: usize,
},
TooManySources,
}Expand description
Failure to create or use a source coordinate or retain another source.
Variants
UnrepresentableOffset
A host byte index cannot be represented by the compiler coordinate type.
OffsetOutOfBounds
A byte offset is beyond the exclusive end of a source document.
ReversedRange
The start of a range follows its end.
SourceMismatch
A range identifies a different source document.
SourceTooLarge
Source byte offsets must fit in the compiler’s u32 coordinate space.
TooManySources
All representable compilation-local IDs have been allocated.