pub struct SourceCandidate { /* private fields */ }Expand description
A physical source document advertised as a candidate for a module name.
Its provider-scoped CandidateId, physical SourceOrigin, display
label, and immutable bytes are independent. In particular, custom and
in-memory sources do not need to invent filesystem paths.
Implementations
Sourceimpl SourceCandidate
impl SourceCandidate
Sourcepub fn new(
identity: impl Into<CandidateId>,
origin: SourceOrigin,
label: impl Into<Arc<str>>,
bytes: impl Into<Arc<[u8]>>,
) -> Self
pub fn new( identity: impl Into<CandidateId>, origin: SourceOrigin, label: impl Into<Arc<str>>, bytes: impl Into<Arc<[u8]>>, ) -> Self
Create a source candidate.
Sourcepub fn identity(&self) -> &CandidateId
pub fn identity(&self) -> &CandidateId
Return this candidate’s stable identity within its provider.
Sourcepub fn origin(&self) -> &SourceOrigin
pub fn origin(&self) -> &SourceOrigin
Return the physical origin of the document.
Return the shared allocation containing the immutable source bytes.