#[repr(u8)]pub enum AccessKeyword {
Access = 0,
MaxAccess = 1,
MinAccess = 2,
}Expand description
Records which access keyword was used in the source MIB.
SMIv1 uses ACCESS, SMIv2 uses MAX-ACCESS, and compliance statements use MIN-ACCESS.
The resolved access value is stored separately as Access.
Variants
Access = 0
SMIv1 ACCESS clause.
MaxAccess = 1
SMIv2 MAX-ACCESS clause.
MinAccess = 2
MIN-ACCESS clause in MODULE-COMPLIANCE refinements.