DiagCode

Enum DiagCode 

pub enum DiagCode {
Show 194 variants UnexpectedCharacter, UnterminatedString, UnterminatedHexBinStr, MissingHexBinSuffix, HexStringMul2, BinStringMul8, HexStringInvalidChar, BinStringInvalidChar, IdentifierUnderscore, IdentifierHyphenEnd, IdentifierLength64, IdentifierLength32, BadIdentifierCase, ParseError, InvalidU32, InvalidI64, KeywordReserved, InvalidHexRange, NumberLeadingZero, MissingComma, MissingModuleIdentity, RevisionLastUpdated, RevisionNotDescending, RevisionAfterUpdate, DateCharacter, DateLength, DateMonth, DateDay, DateHour, DateMinutes, DateValue, DateYear2Digits, DateInFuture, DateInPast, UnknownDefinitionType, UnknownTypeSyntax, UnknownConstraintType, UnknownRangeValue, MinMaxRange, UnknownOidComponent, UnknownDefvalType, BitsNumberNegative, BitsNumberTooLarge, BitsNumberLarge, EnumZero, EnumValueOutOfRange, EnumNameRedefinition, EnumValueRedefinition, BitsNameRedefinition, BitsValueRedefinition, ModuleIdentityNotFirst, ModuleIdentityMultiple, MacroNotImported, EmptyDescription, EmptyRevisionDescription, EmptyReference, EmptyOrganization, EmptyContact, EmptyUnits, EmptyFormat, ModuleNameSuffix, MacroNotAllowed, ChoiceNotAllowed, TaggedTypeNotAllowed, ImportNotFound, ImportModuleNotFound, TypeUnknown, TypeCycle, OidOrphan, TrapNumberOverflow, IndexUnresolved, ObjectsUnresolved, IdentifierHyphenSMIv2, GroupNotAccessible, NotifObjectNotObject, NotifObjectAccess, NotifNotReversible, NotifIdTooLarge, MalformedHexDefval, MalformedBinDefval, DefvalUnresolved, VariationAccessNotifOnly, GroupMemberUnresolved, IndexNotObject, AugmentsNotObject, AugmentNested, NotifNoOid, PrimitiveTypeMissing, IntegerInSMIv2, IndexIntegerNoRange, IndexNegativeRange, DefvalBasetype, DefvalRange, DefvalEnum, DefvalBits, CounterDefvalIllegal, IndexCounterIllegal, RangeBounds, ConstraintEmptyIntersection, RangeExchanged, RangeOverlap, RangeAscending, SizeIllegal, RangeIllegal, CounterRangeIllegal, SubtypeEnumIllegal, SubtypeBitsIllegal, ParentTable, ParentRow, ParentColumn, ParentScalar, ParentNode, ParentNotification, ParentGroup, ParentCompliance, ParentCapabilities, RowSubidentifierOne, IndexElementNoSize, IndexIllegalBasetype, LastSubidZero, OidRecursive, OidRegistered, OidReuse, SequenceNoColumn, SequenceMissingColumn, SequenceOrder, SequenceTypeMismatch, IndexExceedsTooLarge, AccessInvalidSMIv1, AccessWriteOnlySMIv2, AccessTableIllegal, AccessRowIllegal, AccessCounterIllegal, ScalarNotCreatable, MaxAccessInSMIv1, AccessInSMIv2, StatusInvalidSMIv1, StatusInvalidSMIv2, TypeStatusDeprecated, TypeStatusObsolete, GroupMembership, GroupMemberMixed, GroupObjectsNotification, GroupNotificationsObject, GroupObjectStatus, ComplianceGroupStatus, ComplianceObjectStatus, ComplianceGroupInvalid, RefinementExists, OptionalGroupExists, RefinementNotListed, ComplianceMemberNotLocal, TimeticksRangeIllegal, StatusInvalidCapabilities, ImportDuplicate, ImportUnused, BasetypeNotImported, DescriptionMissing, TCNested, TypeAssignmentSMIv2, TableNameTable, RowNameEntry, RowNameTableName, NamedNumbersAscending, HyphenInLabel, OpaqueSMIv2, InvalidFormat, TypeWithoutFormat, TypeUnreferenced, GroupUnreferenced, ObsoleteImport, IdentifierCaseMatch, TrapInSMIv2, NodeImplicit, ModuleIdentityReg, RowStatusDefault, RowStatusAccess, StorageTypeDefault, TAddressTDomain, IndexAccessible, IndexNotAccessible, IndexDefval, AccessWriteOnlySMIv1, IpAddressInSyntax, InetAddressPairing, InetAddressTypeSubtyped, InetAddressSpecific, TransportAddressPairing, TransportAddressTypeSubtyped, TransportAddressSpecific, IncludesUnresolved, IncludesDuplicate, CreationRequiresUnresolved, CreationRequiresDuplicate,
}
Identifies a specific diagnostic condition.

Each code has a fixed Severity and belongs to a pipeline phase (lexer, parser, lower, or resolver). Use DiagCode::as_code for the stable kebab-case string representation.

Variants



UnexpectedCharacter



UnterminatedString



UnterminatedHexBinStr



MissingHexBinSuffix



HexStringMul2



BinStringMul8



HexStringInvalidChar



BinStringInvalidChar



IdentifierUnderscore



IdentifierHyphenEnd



IdentifierLength64



IdentifierLength32



BadIdentifierCase



ParseError



InvalidU32



InvalidI64



KeywordReserved



InvalidHexRange



NumberLeadingZero



MissingComma



MissingModuleIdentity



RevisionLastUpdated



RevisionNotDescending



RevisionAfterUpdate



DateCharacter



DateLength



DateMonth



DateDay



DateHour



DateMinutes



DateValue



DateYear2Digits



DateInFuture



DateInPast



UnknownDefinitionType



UnknownTypeSyntax



UnknownConstraintType



UnknownRangeValue



MinMaxRange



UnknownOidComponent



UnknownDefvalType



BitsNumberNegative



BitsNumberTooLarge



BitsNumberLarge



EnumZero



EnumValueOutOfRange



EnumNameRedefinition



EnumValueRedefinition



BitsNameRedefinition



BitsValueRedefinition



ModuleIdentityNotFirst



ModuleIdentityMultiple



MacroNotImported



EmptyDescription



EmptyRevisionDescription



EmptyReference



EmptyOrganization



EmptyContact



EmptyUnits



EmptyFormat



ModuleNameSuffix



MacroNotAllowed



ChoiceNotAllowed



TaggedTypeNotAllowed



ImportNotFound



ImportModuleNotFound



TypeUnknown



TypeCycle



OidOrphan



TrapNumberOverflow



IndexUnresolved



ObjectsUnresolved



IdentifierHyphenSMIv2



GroupNotAccessible



NotifObjectNotObject



NotifObjectAccess



NotifNotReversible



NotifIdTooLarge



MalformedHexDefval



MalformedBinDefval



DefvalUnresolved



VariationAccessNotifOnly



GroupMemberUnresolved



IndexNotObject



AugmentsNotObject



AugmentNested



NotifNoOid



PrimitiveTypeMissing



IntegerInSMIv2



IndexIntegerNoRange



IndexNegativeRange



DefvalBasetype



DefvalRange



DefvalEnum



DefvalBits



CounterDefvalIllegal



IndexCounterIllegal



RangeBounds



ConstraintEmptyIntersection



RangeExchanged



RangeOverlap



RangeAscending



SizeIllegal



RangeIllegal



CounterRangeIllegal



SubtypeEnumIllegal



SubtypeBitsIllegal



ParentTable



ParentRow



ParentColumn



ParentScalar



ParentNode



ParentNotification



ParentGroup



ParentCompliance



ParentCapabilities



RowSubidentifierOne



IndexElementNoSize



IndexIllegalBasetype



LastSubidZero



OidRecursive



OidRegistered



OidReuse



SequenceNoColumn



SequenceMissingColumn



SequenceOrder



SequenceTypeMismatch



IndexExceedsTooLarge



AccessInvalidSMIv1



AccessWriteOnlySMIv2



AccessTableIllegal



AccessRowIllegal



AccessCounterIllegal



ScalarNotCreatable



MaxAccessInSMIv1



AccessInSMIv2



StatusInvalidSMIv1



StatusInvalidSMIv2



TypeStatusDeprecated



TypeStatusObsolete



GroupMembership



GroupMemberMixed



GroupObjectsNotification



GroupNotificationsObject



GroupObjectStatus



ComplianceGroupStatus



ComplianceObjectStatus



ComplianceGroupInvalid



RefinementExists



OptionalGroupExists



RefinementNotListed



ComplianceMemberNotLocal



TimeticksRangeIllegal



StatusInvalidCapabilities



ImportDuplicate



ImportUnused



BasetypeNotImported



DescriptionMissing



TCNested



TypeAssignmentSMIv2



TableNameTable



RowNameEntry



RowNameTableName



NamedNumbersAscending



HyphenInLabel



OpaqueSMIv2



InvalidFormat



TypeWithoutFormat



TypeUnreferenced



GroupUnreferenced



ObsoleteImport



IdentifierCaseMatch



TrapInSMIv2



NodeImplicit



ModuleIdentityReg



RowStatusDefault



RowStatusAccess



StorageTypeDefault



TAddressTDomain



IndexAccessible



IndexNotAccessible



IndexDefval



AccessWriteOnlySMIv1



IpAddressInSyntax



InetAddressPairing



InetAddressTypeSubtyped



InetAddressSpecific



TransportAddressPairing



TransportAddressTypeSubtyped



TransportAddressSpecific



IncludesUnresolved



IncludesDuplicate



CreationRequiresUnresolved



CreationRequiresDuplicate

Implementations

Source

impl DiagCode

pub fn as_code(self) -> &'static str

Returns the stable kebab-case string representation (e.g. "parse-error").

pub fn from_code(s: &str) -> Option<DiagCode>

Parses a kebab-case code string into a DiagCode, returning None if unrecognized.

pub fn severity(self) -> Severity

Returns the fixed Severity for this diagnostic code.

pub fn phase(self) -> &'static str

Returns the pipeline phase that emits this diagnostic (e.g. "lexer", "resolver").