pub struct ByteOffset(pub u32);Expand description
A byte position in source text.
Wraps a u32 offset. The sentinel value ByteOffset::SYNTHETIC marks
positions that do not correspond to real source text.
Tuple Fields
0: u32Implementations
Sourceimpl ByteOffset
impl ByteOffset
Sourcepub const SYNTHETIC: ByteOffset
pub const SYNTHETIC: ByteOffset
Sentinel value for positions not backed by source text (e.g. base modules).