pub struct OidTree { /* private fields */ }Expand description
Implementations
Sourceimpl OidTree
impl OidTree
Sourcepub fn walk_oid(&self, start: NodeId, oid: &Oid) -> (NodeId, bool)
pub fn walk_oid(&self, start: NodeId, oid: &Oid) -> (NodeId, bool)
Walk the tree from start following arcs in oid.
Returns (last_matched_node, true) if all arcs matched, or
(deepest_matched_node, false) if the walk stopped early.
Sourcepub fn subtree(&self, start: NodeId) -> SubtreeIter<'_> ⓘ
pub fn subtree(&self, start: NodeId) -> SubtreeIter<'_> ⓘ
Depth-first iterator over a subtree rooted at start.
Sourcepub fn all_nodes(&self) -> SubtreeIter<'_> ⓘ
pub fn all_nodes(&self) -> SubtreeIter<'_> ⓘ
Depth-first iterator over all nodes (excluding root).
Sourcepub fn longest_prefix(&self, oid: &Oid) -> NodeId
pub fn longest_prefix(&self, oid: &Oid) -> NodeId
Find the deepest node matching a prefix of oid, starting from root.
Sourcepub fn longest_prefix_from(&self, start: NodeId, oid: &Oid) -> NodeId
pub fn longest_prefix_from(&self, start: NodeId, oid: &Oid) -> NodeId
Find the deepest node matching a prefix of oid, starting from start.